package com.xinda.iot.service;

import com.xinda.common.core.domain.AjaxResult;
import com.xinda.iot.domain.Standard;
import com.xinda.iot.model.IdAndName;

import java.util.List;

/**
 * 产品分类Service接口
 *
 * @author kerwincui
 * @date 2021-12-16
 */
public interface IStandardService
{
    /**
     * 查询产品分类
     *
     * @param standardId 产品分类主键
     * @return 产品分类
     */
    public Standard selectStandardByStandardId(Long standardId);

    /**
     * 查询产品分类列表
     *
     * @param standard 产品分类
     * @return 产品分类集合
     */
    public List<Standard> selectStandardList(Standard standard);

    /**
     * 查询产品简短分类列表
     *
     * @return 产品分类集合
     */
    public List<IdAndName> selectStandardShortList(Standard standard);

    /**
     * 新增产品分类
     *
     * @param standard 产品分类
     * @return 结果
     */
    public int insertStandard(Standard standard);

    /**
     * 修改产品分类
     *
     * @param standard 产品分类
     * @return 结果
     */
    public int updateStandard(Standard standard);

    /**
     * 批量删除产品分类
     *
     * @param standardIds 需要删除的产品分类主键集合
     * @return 结果
     */
    public AjaxResult deleteStandardByStandardIds(Long[] standardIds);

    /**
     * 删除产品分类信息
     *
     * @param standardId 产品分类主键
     * @return 结果
     */
    public int deleteStandardByStandardId(Long standardId);

    public int cloneStandard(Standard standard);
}
